@@ -51,11 +51,11 @@ static struct {
 	{ GTHUMB_STOCK_IMAGE,               image_24_rgba,               NULL },
 	{ GTHUMB_STOCK_INDEX_IMAGE,         index_image_16_rgba,               NULL },
 	{ GTHUMB_STOCK_INVERT,              invert_16_rgba,              NULL },
+	{ GTHUMB_STOCK_LIBRARY,             library_19_rgba,             NULL },	
 	{ GTHUMB_STOCK_LEVELS,              levels_22_rgba,              levels_16_rgba },
 	{ GTHUMB_STOCK_MIRROR,              mirror_24_rgba,              mirror_16_rgba },
-	{ GTHUMB_STOCK_NEXT_IMAGE,          next_image_24_rgba,          NULL },
 	{ GTHUMB_STOCK_POSTERIZE,           posterize_22_rgba,           posterize_16_rgba },
-	{ GTHUMB_STOCK_PREVIOUS_IMAGE,      prev_image_24_rgba,          NULL },
+	{ GTHUMB_STOCK_REDEYE_REMOVAL,      redeye_removal_16_rgba,      NULL },
 	{ GTHUMB_STOCK_REDUCE_COLORS,       reduce_colors_16_rgba,       NULL },
 	{ GTHUMB_STOCK_RESET,               reset_16_rgba,               NULL },
 	{ GTHUMB_STOCK_RESIZE,              resize_22_rgba,              resize_16_rgba },
@@ -68,7 +68,8 @@ static struct {
 	{ GTHUMB_STOCK_SLIDESHOW,           slideshow_24_rgba,           slideshow_16_rgba },
 	{ GTHUMB_STOCK_SWAP,                swap_24_rgba,                swap_16_rgba },
 	{ GTHUMB_STOCK_THRESHOLD,           threshold_16_rgba,           NULL },
-	{ GTHUMB_STOCK_TRANSFORM,           transform_24_rgba,           transform_16_rgba }
+	{ GTHUMB_STOCK_TRANSFORM,           transform_24_rgba,           transform_16_rgba },
+	{ GTHUMB_STOCK_ZOOM_WIDTH,	    zoom_width_24_rgba,		 zoom_width_16_rgba }
 };
 
 
