@@ -3,7 +3,7 @@
 /*
  *  GThumb
  *
- *  Copyright (C) 2001 The Free Software Foundation, Inc.
+ *  Copyright (C) 2001, 2003 The Free Software Foundation, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -73,17 +73,17 @@
 #include <math.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include "pixbuf-utils.h"
+#include "file-utils.h"
 
 #ifdef HAVE_LIBTIFF
 #include <tiffio.h>
 #endif /* HAVE_LIBTIFF */
 
-#ifdef HAVE_LIBJPEG
 #include <stdlib.h>
 #include <setjmp.h>
 #include <jpeglib.h>
-#endif /* HAVE_LIBJPEG */
 
 
 enum {
@@ -213,6 +213,57 @@ _gdk_pixbuf_copy_mirror (GdkPixbuf *src,
 }
 
 
+/*
+ * Returns a transformed image.
+ */
+GdkPixbuf *
+_gdk_pixbuf_transform (GdkPixbuf* src, 
+				GthTransform transform)
+{
+	GdkPixbuf *temp = NULL, *dest = NULL;
+	
+	if (!src) return NULL;
+	
+	switch (transform) {
+	case GTH_TRANSFORM_NONE:
+		dest = src;
+		g_object_ref (dest);
+		break;
+	case GTH_TRANSFORM_FLIP_H:
+		dest = _gdk_pixbuf_copy_mirror (src, TRUE, FALSE);
+		break;
+	case GTH_TRANSFORM_ROTATE_180:
+		dest = _gdk_pixbuf_copy_mirror (src, TRUE, TRUE);
+		break;
+	case GTH_TRANSFORM_FLIP_V:
+		dest = _gdk_pixbuf_copy_mirror (src, FALSE, TRUE);
+		break;
+	case GTH_TRANSFORM_TRANSPOSE:
+		temp = _gdk_pixbuf_copy_rotate_90 (src, FALSE);
+		dest = _gdk_pixbuf_copy_mirror (temp, TRUE, FALSE);
+		g_object_unref (temp);
+		break;
+	case GTH_TRANSFORM_ROTATE_90:
+		dest = _gdk_pixbuf_copy_rotate_90 (src, FALSE);
+		break;
+	case GTH_TRANSFORM_TRANSVERSE:
+		temp = _gdk_pixbuf_copy_rotate_90 (src, FALSE);
+		dest = _gdk_pixbuf_copy_mirror (temp, FALSE, TRUE);
+		g_object_unref (temp);
+		break;
+	case GTH_TRANSFORM_ROTATE_270:
+		dest = _gdk_pixbuf_copy_rotate_90 (src, TRUE);
+		break;
+	default:
+		dest = src;
+		g_object_ref (dest);
+		break;
+	}
+	
+	return dest;
+}
+
+
 void
 pixmap_from_xpm (const char **data, 
 		 GdkPixmap **pixmap, 
@@ -508,10 +559,6 @@ _gdk_pixbuf_hv_gradient (GdkPixbuf *pixbuf,
 }
 
 
-
-
-
-#ifdef HAVE_LIBJPEG
 
 /* error handler data */
 struct error_handler_data {
@@ -564,20 +611,20 @@ _gdk_pixbuf_save_as_jpeg (GdkPixbuf     *pixbuf,
 			  char         **values,
 			  GError       **error)
 {
-	FILE         *file;
 	struct jpeg_compress_struct cinfo;
 	struct error_handler_data jerr;
-	guchar       *buf = NULL;
-	guchar       *ptr;
-	guchar       *pixels = NULL;
-	int           quality     = 75; /* default; must be between 0 and 100 */
-	int           smoothing   = 0;
-	gboolean      optimize    = FALSE;
-	gboolean      progressive = FALSE;
-	int           i, j;
-	int           w, h = 0;
-	int           rowstride = 0;
-	int           bpp;
+	FILE              *file;
+	guchar            *buf = NULL;
+	guchar            *ptr;
+	guchar            *pixels = NULL;
+	volatile int       quality = 85; /* default; must be between 0 and 100 */
+	volatile int       smoothing = 0;
+	volatile gboolean  optimize = FALSE;
+	volatile gboolean  progressive = FALSE;
+	int                i, j;
+	int                w, h = 0;
+	int                rowstride = 0;
+	volatile int       bpp;
 
 	if (keys && *keys) {
 		char **kiter = keys;
@@ -766,10 +813,6 @@ _gdk_pixbuf_save_as_jpeg (GdkPixbuf     *pixbuf,
 	return TRUE;
 }
 
-#endif
-
-
-
 
 
 #ifdef HAVE_LIBTIFF
@@ -1018,7 +1061,7 @@ rle_write (FILE   *fp,
 	int     repeat = 0;
 	int     direct = 0;
 	guchar *from   = buffer;
-	int     x;
+	guint   x;
 	
 	for (x = 1; x < width; ++x) {
 		if (memcmp (buffer, buffer + bytes, bytes)) {
@@ -1249,11 +1292,13 @@ _gdk_pixbuf_savev (GdkPixbuf    *pixbuf,
 		   GError      **error)
 {
 	gboolean   result;
-	
+
 	g_return_val_if_fail (pixbuf != NULL, TRUE);
 	g_return_val_if_fail (filename != NULL, TRUE);
 	g_return_val_if_fail (type != NULL, TRUE);
 
+	filename = get_file_path_from_uri (filename);
+
 #ifdef HAVE_LIBTIFF
 	if (strcmp (type, "tiff") == 0) 
 		result = _gdk_pixbuf_save_as_tiff (pixbuf, 
@@ -1262,14 +1307,12 @@ _gdk_pixbuf_savev (GdkPixbuf    *pixbuf,
 						   error);
 	else
 #endif
-#ifdef HAVE_LIBJPEG
 	if (strcmp (type, "jpeg") == 0) 
 		result = _gdk_pixbuf_save_as_jpeg (pixbuf, 
 						   filename, 
 						   keys, values, 
 						   error);
 	else
-#endif
 	if ((strcmp (type, "x-tga") == 0) || (strcmp (type, "tga") == 0))
 		result = _gdk_pixbuf_save_as_tga (pixbuf, 
 						  filename, 
@@ -1285,7 +1328,7 @@ _gdk_pixbuf_savev (GdkPixbuf    *pixbuf,
 
 
 static void
-collect_save_options (va_list   opts,
+collect_save_options (va_list    opts,
 		      char    ***keys,
 		      char    ***vals)
 {
@@ -1349,3 +1392,50 @@ _gdk_pixbuf_save (GdkPixbuf    *pixbuf,
 
 	return result;
 }
+
+
+gboolean
+scale_keepping_ratio (int *width,
+		      int *height,
+		      int  max_width,
+		      int  max_height)
+{
+	double   w = *width;
+	double   h = *height;
+	double   max_w = max_width;
+	double   max_h = max_height;
+	double   factor;
+	int      new_width, new_height;
+	gboolean modified;
+
+	if ((*width < max_width) && (*height < max_height)) 
+		return FALSE;
+
+	factor = MIN (max_w / w, max_h / h);
+	new_width  = MAX ((int) floor (w * factor + 0.50), 1);
+	new_height = MAX ((int) floor (h * factor + 0.50), 1);
+	
+	modified = (new_width != *width) || (new_height != *height);
+
+	*width = new_width;
+	*height = new_height;
+
+	return modified;
+}
+
+
+GdkPixbuf*
+create_void_pixbuf (int width,
+		    int height)
+{
+	GdkPixbuf *p;
+
+	p = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
+			    TRUE,
+			    8,
+			    width,
+			    height);
+	gdk_pixbuf_fill (p, 0xFFFFFF00);
+
+	return p;
+}
