@@ -120,14 +120,16 @@ typedef enum { /*< skip >*/
 } GthPrintUnit;
 
 
-/* keep the order of the items in sync with the order of the 
- * sort_by_radio_list structure in the file menu.h */
+/* keep the order of the items in sync with the order of the
+ * sort_names structure in the file libgthumb/catalog.c */
 typedef enum { /*< skip >*/
 	GTH_SORT_METHOD_NONE,
 	GTH_SORT_METHOD_BY_NAME,
 	GTH_SORT_METHOD_BY_PATH,
 	GTH_SORT_METHOD_BY_SIZE,
 	GTH_SORT_METHOD_BY_TIME,
+	GTH_SORT_METHOD_BY_EXIF_DATE,
+	GTH_SORT_METHOD_BY_COMMENT,
 	GTH_SORT_METHOD_MANUAL
 } GthSortMethod;
 
@@ -160,10 +162,12 @@ typedef enum { /*< skip >*/
 	GTH_CAPTION_EXIF_APERTURE_VALUE = 1 << 9,
 	GTH_CAPTION_EXIF_FOCAL_LENGTH   = 1 << 10,
 	GTH_CAPTION_EXIF_DATE_TIME      = 1 << 11,
-	GTH_CAPTION_EXIF_CAMERA_MODEL   = 1 << 12
+	GTH_CAPTION_EXIF_CAMERA_MODEL   = 1 << 12,
+	GTH_CAPTION_PLACE               = 1 << 13,
+	GTH_CAPTION_DATE_TIME           = 1 << 14
 } GthCaptionFields;
 
- 
+
 typedef enum { /*< skip >*/
 	GTH_FRAME_STYLE_NONE               = 1 << 0,
 	GTH_FRAME_STYLE_SIMPLE             = 1 << 1,
@@ -204,14 +208,23 @@ typedef enum { /*< skip >*/
 
 
 typedef enum { /*< skip >*/
-	GTH_TRANSFORM_ROTATE_0,
-	GTH_TRANSFORM_ROTATE_90,
-	GTH_TRANSFORM_ROTATE_180,
-	GTH_TRANSFORM_ROTATE_270,
-	GTH_TRANSFORM_NONE,
-	GTH_TRANSFORM_MIRROR,
-	GTH_TRANSFORM_FLIP
+	GTH_TRANSFORM_NONE = 1,		/* no transformation */
+	GTH_TRANSFORM_FLIP_H,		/* horizontal flip */
+	GTH_TRANSFORM_ROTATE_180, 	/* 180-degree rotation */
+	GTH_TRANSFORM_FLIP_V,		/* vertical flip */
+	GTH_TRANSFORM_TRANSPOSE,	/* transpose across UL-to-LR axis (= rotate_90 + flip_h) */
+	GTH_TRANSFORM_ROTATE_90,	/* 90-degree clockwise rotation */
+	GTH_TRANSFORM_TRANSVERSE,	/* transpose across UR-to-LL axis (= rotate_90 + flip_v) */
+	GTH_TRANSFORM_ROTATE_270	/* 270-degree clockwise */
 } GthTransform;
+/* The GthTransform numeric values range from 1 to 8, corresponding to
+the valid range of Exif orientation tags. The name associated with each
+numeric valid describes the data transformation required that will allow
+the orientation value to be reset to "1" without changing the displayed image.
+GthTransform and ExifShort values are interchangeably in a number of places.
+The main difference is that ExifShort can have a value of zero, corresponding
+to an error or an absence of an Exif orientation tag. See bug 361913 for
+additional details. */
 
 
 typedef enum { /*< skip >*/
@@ -222,18 +235,16 @@ typedef enum { /*< skip >*/
 } GthDropPosition;
 
 
-typedef void (*ErrorFunc)      (gpointer data);
-
-typedef void (*DoneFunc)       (gpointer data);
-
-typedef void (*ProgressFunc)   (gfloat percent, 
-				gpointer data);
-
-typedef void (*AreaReadyFunc)  (guint x,
-				guint y, 
-				guint w, 
-				guint h, 
-				gpointer data);
+typedef void (*ErrorFunc)          (gpointer data);
+typedef void (*DoneFunc)           (gpointer data);
+typedef void (*ProgressFunc)       (gfloat percent,
+				    gpointer data);
+typedef void (*AreaReadyFunc)      (guint x,
+				    guint y,
+				    guint w,
+				    guint h,
+				    gpointer data);
+typedef gboolean (*GthVisibleFunc) (gpointer data);
 
 
 #endif /* TYPEDEFS_H */
