@@ -24,13 +24,13 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-
+#include <unistd.h>
+#include <string.h>
+#include <glib/gi18n.h>
 #include <gconf/gconf-client.h>
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-help.h>
 #include <libgnome/gnome-url.h>
-#include <libgnomeui/libgnomeui.h>
-#include <libbonoboui.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 
 #include "async-pixbuf-ops.h"
@@ -42,6 +42,7 @@
 #include "dlg-catalog.h"
 #include "dlg-categories.h"
 #include "dlg-change-date.h"
+#include "dlg-reset-exif.h"
 #include "dlg-comment.h"
 #include "dlg-convert.h"
 #include "dlg-file-utils.h"
@@ -49,6 +50,7 @@
 #include "dlg-posterize.h"
 #include "dlg-color-balance.h"
 #include "dlg-preferences.h"
+#include "dlg-redeye-removal.h"
 #include "dlg-rename-series.h"
 #include "dlg-scale-image.h"
 #include "dlg-crop.h"
@@ -57,6 +59,7 @@
 #include "gconf-utils.h"
 #include "gth-pixbuf-op.h"
 #include "gth-viewer.h"
+#include "gth-utils.h"
 #include "gthumb-error.h"
 #include "gthumb-module.h"
 #include "gtk-utils.h"
@@ -113,7 +116,7 @@ gth_window_activate_action_image_open_with (GtkAction  *action,
 	GList      *list;
 
 	image_filename = gth_window_get_image_filename (window);
-	if (image_filename == NULL) 
+	if (image_filename == NULL)
 		return;
 
 	list = g_list_append (NULL, g_strdup (image_filename));
@@ -132,8 +135,8 @@ gth_window_activate_action_file_save (GtkAction *action,
 	GthWindow   *window = GTH_WINDOW (data);
 	ImageViewer *image_viewer = gth_window_get_image_viewer (window);
 
-	gth_window_save_pixbuf (window, 
-				image_viewer_get_current_pixbuf (image_viewer), 
+	gth_window_save_pixbuf (window,
+				image_viewer_get_current_pixbuf (image_viewer),
 				gth_window_get_image_filename (window));
 }
 
@@ -189,6 +192,7 @@ gth_window_activate_action_file_print (GtkAction *action,
 				       GthWindow *window)
 {
 	GList    *list;
+	char     *tmp_dir;
 	char     *tmp_filename = NULL;
 	gboolean  remove_temp_file = FALSE;
 
@@ -208,7 +212,13 @@ gth_window_activate_action_file_print (GtkAction *action,
 			GList      *current;
 
 			g_object_ref (pixbuf);
-			tmp_filename = get_temp_file_name (".jpeg");
+			tmp_dir = get_temp_dir_name ();
+			if (tmp_dir == NULL)
+			{
+				_gtk_error_dialog_run (GTK_WINDOW (window), _("Could not create a temporary folder"));
+				return;
+			}
+			tmp_filename = get_temp_file_name (tmp_dir, ".jpeg");
 			if (! _gdk_pixbuf_save (pixbuf,
 						tmp_filename,
 						"jpeg",
@@ -217,6 +227,8 @@ gth_window_activate_action_file_print (GtkAction *action,
 				_gtk_error_dialog_from_gerror_run (GTK_WINDOW (window), &error);
 				g_object_unref (pixbuf);
 				g_free (tmp_filename);
+				dir_remove(tmp_dir);
+				g_free(tmp_dir);
 				return;
 			}
 
@@ -237,7 +249,11 @@ gth_window_activate_action_file_print (GtkAction *action,
 	}
 
 	if (remove_temp_file)
+	{
 		print_catalog_dlg_full (GTK_WINDOW (window), list, print_done_cb, tmp_filename);
+		dir_remove (tmp_dir);
+		g_free (tmp_dir);
+	}
 	else
 		print_catalog_dlg (GTK_WINDOW (window), list);
 
@@ -449,6 +465,13 @@ gth_window_activate_action_alter_image_hue_saturation (GtkAction *action,
 }
 
 
+void
+gth_window_activate_action_alter_image_redeye_removal (GtkAction *action,
+						   GthWindow *window)
+{
+	dlg_redeye_removal (window);
+}
+
 void
 gth_window_activate_action_alter_image_color_balance (GtkAction *action,
 						      GthWindow *window)
@@ -457,13 +480,6 @@ gth_window_activate_action_alter_image_color_balance (GtkAction *action,
 }
 
 
-void
-gth_window_activate_action_alter_image_threshold (GtkAction *action,
-						  gpointer   data)
-{
-}
-
-
 void
 gth_window_activate_action_alter_image_resize (GtkAction *action,
 					       GthWindow *window)
@@ -472,13 +488,6 @@ gth_window_activate_action_alter_image_resize (GtkAction *action,
 }
 
 
-void
-gth_window_activate_action_alter_image_rotate (GtkAction *action,
-					       gpointer   data)
-{
-}
-
-
 void
 gth_window_activate_action_alter_image_crop (GtkAction *action,
 					     GthWindow *window)
@@ -530,6 +539,15 @@ gth_window_activate_action_view_zoom_in (GtkAction *action,
 }
 
 
+void
+gth_window_activate_action_view_zoom_to_width (GtkAction *action,
+                                               gpointer   data)
+{
+        GthWindow *window = GTH_WINDOW (data);
+	image_viewer_set_fit_mode (gth_window_get_image_viewer (window), GTH_FIT_WIDTH_IF_LARGER);
+}
+
+
 void
 gth_window_activate_action_view_zoom_out (GtkAction *action,
 					  gpointer   data)
@@ -553,12 +571,7 @@ gth_window_activate_action_view_zoom_fit (GtkAction *action,
 					  gpointer   data)
 {
 	GthWindow   *window = GTH_WINDOW (data);
-	ImageViewer *image_viewer = gth_window_get_image_viewer (window);
-
-	if (image_viewer->zoom_fit) 
-		image_viewer->zoom_fit = FALSE;
-	else 
-		image_viewer_zoom_to_fit (image_viewer);
+	image_viewer_set_fit_mode (gth_window_get_image_viewer (window), GTH_FIT_SIZE_IF_LARGER);
 }
 
 
@@ -588,11 +601,11 @@ set_wallpaper (const char     *image_path,
 	client = gconf_client_get_default ();
 
 	image_path = get_file_path_from_uri (image_path);
-	if ((image_path == NULL) || ! path_is_file (image_path)) 
+	if ((image_path == NULL) || ! path_is_file (image_path))
 		options = "none";
 
 	else {
-		gconf_client_set_string (client, 
+		gconf_client_set_string (client,
 					 "/desktop/gnome/background/picture_filename",
 					 image_path,
 					 NULL);
@@ -615,8 +628,8 @@ set_wallpaper (const char     *image_path,
 		}
 	}
 
-	gconf_client_set_string (client, 
-				 "/desktop/gnome/background/picture_options", 
+	gconf_client_set_string (client,
+				 "/desktop/gnome/background/picture_options",
 				 options,
 				 NULL);
         g_object_unref (G_OBJECT (client));
@@ -624,7 +637,7 @@ set_wallpaper (const char     *image_path,
 
 
 static char *
-get_wallpaper_filename (int n) 
+get_wallpaper_filename (int n)
 {
 	char *name, *filename;
 
@@ -649,7 +662,7 @@ set_wallpaper_from_window (GthWindow      *window,
 		const char *filename = gth_window_get_image_filename (window);
 		if (filename != NULL)
 			image_path = g_strdup (filename);
-		
+
 	} else {
 		ImageViewer *image_viewer;
 		GdkPixbuf   *pixbuf;
@@ -669,7 +682,7 @@ set_wallpaper_from_window (GthWindow      *window,
 			file_unlink (wallpaper_filename);
 			g_free (wallpaper_filename);
 			wallpaper_filename = get_wallpaper_filename (2);
-			if (path_is_file (wallpaper_filename)) 
+			if (path_is_file (wallpaper_filename))
 				file_unlink (wallpaper_filename);
 		}
 
@@ -762,10 +775,9 @@ gth_window_activate_action_help_about (GtkAction *action,
 	};
 	const char *documenters [] = {
 		"Paolo Bacchilega",
-		"Alexander Kirillov", 
+		"Alexander Kirillov",
 		NULL
 	};
-	const char *translator_credits = _("translator_credits");
 	char       *license_text;
 	const char *license[] = {
                 "gThumb is free software; you can redistribute it and/or modify "
@@ -797,48 +809,16 @@ gth_window_activate_action_help_about (GtkAction *action,
                                "wrap-license", TRUE,
 			       "website", "http://gthumb.sourceforge.net",
                                NULL);
-	
+
         g_free (license_text);
 }
 
 
-static void
-display_help (GthWindow  *window,
-	      const char *section) 
-{
-	GError *err;
-
-	err = NULL;  
-	gnome_help_display ("gthumb", section, &err);
-	
-	if (err != NULL) {
-		GtkWidget *dialog;
-		
-		dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-						 GTK_DIALOG_DESTROY_WITH_PARENT,
-						 GTK_MESSAGE_ERROR,
-						 GTK_BUTTONS_CLOSE,
-						 _("Could not display help: %s"),
-						 err->message);
-		
-		g_signal_connect (G_OBJECT (dialog), "response",
-				  G_CALLBACK (gtk_widget_destroy),
-				  NULL);
-		
-		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-		
-		gtk_widget_show (dialog);
-		
-		g_error_free (err);
-	}
-}
-
-
 void
 gth_window_activate_action_help_help (GtkAction *action,
 				      gpointer   data)
 {
-	display_help (GTH_WINDOW (data), NULL);
+	gthumb_display_help (GTK_WINDOW (data), NULL);
 }
 
 
@@ -846,7 +826,7 @@ void
 gth_window_activate_action_help_shortcuts (GtkAction *action,
 					   gpointer   data)
 {
-	display_help (GTH_WINDOW (data), "shortcuts");
+	gthumb_display_help (GTK_WINDOW (data), "shortcuts");
 }
 
 
@@ -874,6 +854,14 @@ gth_window_activate_action_tools_change_date (GtkAction *action,
 }
 
 
+void
+gth_window_activate_action_tools_reset_exif (GtkAction *action,
+                                              GthWindow *window)
+{
+        dlg_reset_exif (window);
+}
+
+
 void
 gth_window_activate_action_tools_jpeg_rotate (GtkAction *action,
 					      GthWindow *window)
@@ -889,10 +877,10 @@ void
 gth_window_activate_action_tools_jpeg_rotate_right (GtkAction *action,
 						    GthWindow *window)
 {
-	void (*module) (GthWindow *, GthTransform, GthTransform);
+	void (*module) (GthWindow *, GthTransform);
 
 	if (gthumb_module_get ("dlg_apply_jpegtran", (gpointer*) &module))
-		(*module) (window, GTH_TRANSFORM_ROTATE_90, GTH_TRANSFORM_NONE);
+		(*module) (window, GTH_TRANSFORM_ROTATE_90);
 }
 
 
@@ -900,19 +888,8 @@ void
 gth_window_activate_action_tools_jpeg_rotate_left (GtkAction *action,
 						   GthWindow *window)
 {
-	void (*module) (GthWindow *, GthTransform, GthTransform);
+	void (*module) (GthWindow *, GthTransform);
 
 	if (gthumb_module_get ("dlg_apply_jpegtran", (gpointer*) &module))
-		(*module) (window, GTH_TRANSFORM_ROTATE_270, GTH_TRANSFORM_NONE);
-}
-
-
-void
-gth_window_activate_action_tools_jpeg_rotate_auto (GtkAction *action,
-						   GthWindow *window)
-{
-	void (*module) (GthWindow *);
-
-	if (gthumb_module_get ("dlg_apply_jpegtran_from_exif", (gpointer*) &module))
-		(*module) (window);
+		(*module) (window, GTH_TRANSFORM_ROTATE_270);
 }
